Name:           build
Version:        20220429
Release:        1
Summary:        A tool to build binary packages
License:        GPL-2.0-only OR GPL-3.0-only
Url:            https://github.com/openSUSE/obs-build
Source:         https://github.com/openSUSE/obs-build/archive/refs/tags/%{version}.tar.gz
Patch0001:      0001-add-settings.patch
BuildArch:      noarch
Requires:       bash binutils perl tar psmisc build-mkbaselibs
BuildRequires:  bash binutils perl psmisc tar perl-libwww-perl

%description
This is a tool to build binary packages in a safe and reproducible
way. The default is to build in a chroot sandbox, but it also
supports building in a virtual machine for better security.
The build tool can work with multiple package and recipe formats.
The currently supported package formats are deb, rpm, and arch.
The supported recipe formats are spec, dsc, kiwi, and PKGBUILD.

%package mkbaselibs
Summary:        Base lib package for %{name}

%description mkbaselibs
This package contains some files to be installed int the build system to generate
base lib packages.

%package mkdrpms
Summary:        Delta rpms tools
Requires:       deltarpm %{name}

%description mkdrpms
This package contains file to be installed in the build system to generate delta
rpm packages.

%package help
Summary:        Help package for %{name}
BuildArch:      noarch

%description help
This package contains some man help packages for %{name}.

%prep
%autosetup -n obs-build-%{version} -p1

%build

%install
%make_install
%{__install} -m644 settings.xml %{buildroot}/usr/lib/build

%check
for file in build build-*
do
    bash -n ${file} || exit 1
done
if [ `id -u` -ne 0 ]
then
    echo "warning: Not building as root, tests will not run!"
    exit 0
fi
if [ ! -f "%{buildroot}/usr/lib/build/configs/default.conf" ]
then
    echo "warning: No default config, tests will not run!"
    exit 0
fi
cp -a %{buildroot}/usr/lib/build/configs/default.conf configs/
export BUILD_IGNORE_2ND_STAGE=1
export BUILD_DIR=$PWD
sed -i 's,build-mkbaselibs,,' configs/*.conf
./test/testbuild.sh /.build.binaries/

%files
%defattr(-,root,root)
%{_bindir}/build
%{_bindir}/buildvc
%{_bindir}/unrpm
%{_bindir}/pbuild
/usr/lib/build
%exclude /usr/lib/build/mkbaselibs
%exclude /usr/lib/build/baselibs*
%exclude /usr/lib/build/mkdrpms

%files mkbaselibs
%defattr(-,root,root)
%dir /usr/lib/build
/usr/lib/build/mkbaselibs
/usr/lib/build/baselibs*

%files mkdrpms
%defattr(-,root,root)
%dir /usr/lib/build

%files help
%defattr(-,root,root)
%{_mandir}/man1/build.1*
%{_mandir}/man1/unrpm.1*
%{_mandir}/man1/buildvc.1*
%{_mandir}/man1/pbuild.1.gz

%changelog
* Tue May 10 2022 Wei, Qiang <qiang.wei@suse.com> - 20220429-1
- Upgrade to 20220429 version

* Sat Jan 15 2022 houyingchao <houyingchao@huawei.com> - 20211125-1
- Upgrade to 20211125 version

* Thu Jan 07 2021 openEuler miao_kaibo <miaokaibo@outlook.com> - 20191114-324.5
- Add settings.xml for jar

* Mon Jul 27 2020 openEuler Jeffery.Gao <gaojianxing@huawei.com> - 20191114-324.4
- Modify for obs-build access URL

* Fri Mar 06 2020 openEuler Buildteam <buildteam@openeuler.com> - 20191114-324.3
- Rectify the spec file

* Thu Nov 28 2019 catastrowings <jianghuhao1994@163.com> - 20191114-324.2
- openEuler init
